#define LINE_LEFT	0
#define LINE_RIGHT	1
#define LINE_TOP	2
#define LINE_BOTTOM	3

#define TERM_IGNORE	0
#define TERM_ANSI	1

void wrong_key(void);
int ask_yes_no(int what_help, NEWWIN *popup);
void color_on(NEWWIN *win, int index);
void color_off(NEWWIN *win, int index);
void inverse_on(NEWWIN *win);
void inverse_off(NEWWIN *win);
void draw_line(NEWWIN *win, char where);
char * edit_string(NEWWIN *win, int y, int win_width, int max_width, char numbers_only, char *input_string, int what_help);
NEWWIN * create_popup(int n_lines, int n_colls);
void delete_popup(NEWWIN *mywin);
void draw_marker_line(NEWWIN *win);
void mydelwin(NEWWIN *win);
void mydoupdate();
NEWWIN * mynewwin(int nlines, int ncols, int begin_y, int begin_x);
void escape_print(NEWWIN *win, int y, int x, char *str);
void win_header(NEWWIN *win, char *str);
void gui_window_header(char *string);
void error_popup(char *title, int help, char *message, ...);
